#
# spec file for package libmodplug
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define soname 1
Name:           libmodplug
Version:        0.8.8.5
Release:        45.5
Summary:        A MOD playing library
License:        SUSE-Public-Domain
Group:          System/Libraries
Url:            http://modplug-xmms.sourceforge.net
Source:         http://download.sourceforge.net/modplug-xmms/libmodplug-%{version}.tar.gz
Source1:        baselibs.conf
# PATCH-FIX-OPENSUSE libmodplug-timidity.patch -- set paths to openSUSE timidity package
Patch1:         libmodplug-timidity.patch
# PATCH-FIX-UPSTREAM libmodplug-0.8.8.5-fix-missing-include-path.patch -- set includedir in pc file
Patch2:         libmodplug-0.8.8.5-fix-missing-include-path.patch
BuildRequires:  gcc-c++
BuildRequires:  pkg-config
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Libmodplug is the library behind -- Modplug-XMMS is a fully featured, complete
input plugin for XMMS which plays mod-like music formats. It is based on the
mod rendering code from ModPlug, a popular windows mod player written by
Olivier Lapicque, found at http://www.modplug.com/.

%package -n libmodplug%{soname}
Summary:        Development files for libmodplug
Group:          Development/Libraries/C and C++

%description -n libmodplug%{soname}
Modplug library based on the ModPlug sound engine.
- plays 22 different mod formats.
- plays zip, rar, gzip, and bzip2 compressed mods.
- plays timidity's GUS patch files (*.pat).
- plays all types of MIDI files (*.mid).
- plays textfiles written in the ABC music notation (*.abc).

%package devel
Summary:        Development files for libmodplug
Group:          Development/Libraries/C and C++
Requires:       libmodplug%{soname} = %{version}

%description devel
Files needed to program against libmodplug.

%prep
%setup -q
%patch1
%patch2 -p1
sed -i 's/\r$//' ChangeLog

%build
%configure --disable-static
make %{?_smp_mflags} V=1

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print

%post -n libmodplug%{soname} -p /sbin/ldconfig

%postun -n libmodplug%{soname} -p /sbin/ldconfig

%files -n libmodplug%{soname}
%defattr(0644,root,root,0755)
%{_libdir}/%{name}.so.%{soname}*

%files devel
%defattr(0644,root,root,0755)
%doc AUTHORS ChangeLog COPYING NEWS README TODO
%{_includedir}/%{name}
%{_libdir}/%{name}.so
%{_libdir}/pkgconfig/%{name}.pc

%changelog
* Thu Mar 27 2014 tchvatal@suse.com
- Add patch for broken pc file where quite some upstream refer to
  modplug directly without specifying the subdir it is in.
  * libmodplug-0.8.8.5-fix-missing-include-path.patch
* Thu Mar 13 2014 reddwarf@opensuse.org
- Update to version 0.8.8.5
  * Some security patches: CVE-2013-4233, CVE-2013-4234, as well as
    many fixes suggested by static analyzers: clang build-scan, and coverity.
- Remove CVE-2013-4233.patch, CVE-2013-4234.patch and libmodplug-overflow.patch
- Stop using dos2unix
- Run through spec-cleaner
- Use full URL in Source tag
* Tue Oct 22 2013 sbrabec@suse.cz
- Two security fixes (bnc#834483):
  * Fix integer overflow (CVE-2013-4233, CVE-2013-4233.patch).
  * Fix heap overflows (CVE-2013-4234, CVE-2013-4234.patch).
* Thu Mar 15 2012 aj@suse.de
- Fix buffer overflow.
* Fri Aug 12 2011 dimstar@opensuse.org
- Stop using source services.
* Mon Aug  8 2011 sbrabec@suse.cz
- Update to version 0.8.8.4 (bnc#710726):
  * Improve timidity.cfg parsing capability
  * Add source command capability in timidity.cfg
    (useful for debian default)
  * Fix integer overflow in WAV reader (SA45131/A)
  * Fix S3M stack overflow possibility (SA45131/B)
  * Bound seeking and reading in PAT files
  * Fix AMS/AMSv2 and DSM too large by one (SA45131/C)
  * Use bmpvalues in Octamed files when calcuting default tempo
* Wed May 25 2011 sbrabec@suse.cz
- Updated to version 0.8.8.3:
  * Several security fixes (including CVE-2011-1761, bnc#691137).
  * Improve compatibility with MSVC 2010
  * Improve PTM playback (Fix byteswapping)
  * Improve S3M support (ignore corrupted data, bnc#686624)
  * Improve AMF support (bounds checking)
* Sun May 22 2011 davejplater@gmail.com
- Fixed ChangeLog eol encoding with dos2unix.
* Mon Apr 18 2011 ro@suse.de
- fix baselibs.conf file
* Sun Apr  3 2011 reddwarf@opensuse.org
- Updated to version 0.8.8.2
  * Improve compatibility with MSVC 2010
  * Improve PTM playback (Fix byteswapping)
  * Improve S3M support (ignore corrupted data)
  * Improve AMF support (bounds checking)
- Added pkg-config BuildRequire
- Make build verbose
- Remove execution permission from shared library
* Sat Jul 17 2010 reddwarf@opensuse.org
- Updated to version 0.8.8.1
* Tue Feb 16 2010 meissner@suse.de
- added a baselibs.conf (for libxine1 baselibs)
* Wed May  6 2009 sbrabec@suse.cz
- Changes reviewed and signed-off.
* Wed Apr 29 2009 cmorve69@yahoo.es
- Updated to version 0.8.7.
  * small fixes contributed since last release
  * buffer overflow fix (already fixed in openSUSE)
* Tue Apr 21 2009 sbrabec@suse.cz
- Package added to openSUSE Factory - gstreamer-0_10-plugins-bad
  now depend on external libmodplug. Source: OBS home:RedDwarf.
- Rename and split according to shared library policy.
- Updated to version 0.8.6:
  * small fixes contributed since last release
  * fixed libmodplug s3m boundary check overflow vulnerability in
    Amiga MED and OctaMED files (bnc#496541, securityfocus#30801)
- Fixed invalid delete (bnc#443444).
- Fixed timidity.cfg path.
* Mon Mar 23 2009 cmorve69@yahoo.es
- First OBS version, from Packman
* Fri Nov  3 2006 Manfred.Tremmel@iiv.de
- Update to 0.8.4
* Fri Oct 15 2004 Manfred.Tremmel@iiv.de
- some little changes for amd64
* Fri Feb 13 2004 Manfred.Tremmel@iiv.de
- Initial version
